@@ -14,7 +14,12 @@ except ImportError:
     # dummy class of SSLError for ssl none-support environment.
     class SSLError(Exception):
         pass
-import unittest
+
+if sys.version_info[0] == 2 and sys.version_info[1] < 7:
+    import unittest2 as unittest
+else:
+    import unittest
+
 import uuid
 
 # websocket-client
@@ -133,6 +138,9 @@ class WebSocketTest(unittest.TestCase):
 
         self.assertRaises(ValueError, ws._parse_url, "http://www.example.com/r")
 
+        if sys.version_info[0] == 2 and sys.version_info[1] < 7:
+            return
+
         p = ws._parse_url("ws://[2a03:4000:123:83::3]/r")
         self.assertEqual(p[0], "2a03:4000:123:83::3")
         self.assertEqual(p[1], 80)
@@ -215,6 +223,8 @@ class WebSocketTest(unittest.TestCase):
         sock.send(u"こんにちは")
         self.assertEqual(s.sent[1], six.b("\x81\x8fabcd\x82\xe3\xf0\x87\xe3\xf1\x80\xe5\xca\x81\xe2\xc5\x82\xe3\xcc"))
 
+        sock.send("x" * 127)
+
     def testRecv(self):
         # TODO: add longer frame data
         sock = ws.WebSocket()
